User: user57
Date: 02/02/16 20:10:37
Modified: src/main/org/jboss/system ConfigurationException.java
Log:
o extend from NestedException for better stack trace handling
Revision Changes Path
1.4 +27 -32 jboss/src/main/org/jboss/system/ConfigurationException.java
Index: ConfigurationException.java
===================================================================
RCS file:
/cvsroot/jboss/jboss/src/main/org/jboss/system/ConfigurationException.java,v
retrieving revision 1.3
retrieving revision 1.4
diff -u -r1.3 -r1.4
--- ConfigurationException.java 3 Jan 2002 04:01:00 -0000 1.3
+++ ConfigurationException.java 17 Feb 2002 04:10:37 -0000 1.4
@@ -7,59 +7,54 @@
package org.jboss.system;
+import org.jboss.util.NestedException;
+
/**
- * Throw to indicate a non-fatal configuration related problem.
+ * Thrown to indicate a non-fatal configuration related problem.
*
* @see ConfigurationService
*
* @author <a href="mailto:[EMAIL PROTECTED]">Jason Dillon</a>
- * @version <pre>$Revision: 1.3 $</pre>
+ * @version <tt>$Revision: 1.4 $</tt>
*/
public class ConfigurationException
- extends Exception
+ extends NestedException
{
- /** The root cause of this exception */
- protected Throwable cause;
-
/**
- * Construct a <tt>ConfigurationException</tt>.
+ * Construct a <tt>ConfigurationException</tt> with the specified detail
+ * message.
*
* @param message The exception detail message.
*/
- public ConfigurationException(final String message) {
- super(message);
+ public ConfigurationException(String msg) {
+ super(msg);
}
-
+
/**
- * Construct a <tt>ConfigurationException</tt>.
+ * Construct a <tt>ConfigurationException</tt> with the specified detail
+ * message and nested <tt>Throwable</tt>.
*
* @param message The exception detail message.
* @param cause The detail cause of the exception.
*/
- public ConfigurationException(final String message,
- final Throwable cause)
- {
- super(message);
- this.cause = cause;
+ public ConfigurationException(String msg, Throwable nested) {
+ super(msg, nested);
}
-
+
/**
- * Get the cause of the exception.
+ * Construct a <tt>ConfigurationException</tt> with the specified
+ * nested <tt>Throwable</tt>.
*
- * @return The cause of the exception or null if there is none.
+ * @param nested Nested <tt>Throwable</tt>.
*/
- public Throwable getCause() {
- return cause;
+ public ConfigurationException(Throwable nested) {
+ super(nested);
}
-
+
/**
- * Return a string representation of the exception.
- *
- * @return A string representation.
+ * Construct a <tt>ConfigurationException</tt> with no detail.
*/
- public String toString() {
- return cause == null ?
- super.toString() :
- super.toString() + ", Cause: " + cause;
+ public ConfigurationException() {
+ super();
}
}
_______________________________________________
@@ -7,59 +7,54 @@
*
- * @param message The exception detail message.
+ * @param msg Detail message.
*/
@@ -7,59 +7,54 @@
*
- * @param message The exception detail message.
- * @param cause The detail cause of the exception.
+ * @param msg Detail message.
+ * @param nested Nested <tt>Throwable</tt>.
*/
Jboss-development mailing list
[EMAIL PROTECTED]
https://lists.sourceforge.net/lists/listinfo/jboss-development